      PROGRAM MULTI
C
C  MAIN CALLING PROGRAM FOR SOLVING MULTI-LEVEL NON-LTE PROBLEMS
C  FOR DOCUMENTATION, COMMENTS ON EXPERIENCE WITH THE CODE AND
C  A DESCRIPTION OF THE METHOD SEE
C  CARLSSON 1986: 'UPPSALA ASTRONOMICAL OBSERVATORY, REPORT NO. 33'.
C  A MORE DETAILED DESCRIPTION OF THE METHOD IS IN
C  SCHARMER, CARLSSON 1985: 'JOURNAL OF COMPUTATIONAL PHYSICS',59,56
C  FOR LIST OF VARIABLES AND FILES, SEE  ROUTINE  START.
C
C  PARAMETER VARIABLES:
C  MDEP1  NUMBER OF DEPTH POINTS. MUST BE THE NUMBER ACTUALLY USED.
C  MK1    NUMBER OF LEVELS INCLUDING CONTINUUM LEVELS. -''-.
C  MDEP   MAXIMUM NUMBER OF DEPTH POINTS.
C  MK     MAXIMUM NUMBER OF LEVELS INCLUDING CONTINUUM LEVELS
C  MLINE  MAXIMUM NUMBER OF BOUND-BOUND LINES
C  MWIDE  MAXIMUM NUMBER OF BROAD LINES + CONTINUA IN DETAIL
C  MRAD   MLINE+MWIDE
C  MRFIX  MAXIMUM NUMBER OF FIXED TRANSITIONS
C  MQ     MAXIMUM NUMBER OF FREQUENCY POINTS IN ONE TRANSITION
C  MMU    MAXIMUM NUMBER OF ANGLE POINTS
C
C  ONLY MDEP1 AND MK1 MUST BE EQUAL TO THE VALUES ACTUALLY USED, NDEP1
C  AND NK1. THE OTHERS MAY BE LARGER THAN VALUES ACTUALLY USED.
C
C: MULTI  90-07-31  MODIFICATIONS: (MATS CARLSSON)
C:        CHANGED TO CONTAIN DECLARATION OF W AND E
C:        THESE PASSED IN ARGUMENT LIST INSTEAD OF IN COMMON TO
C:        AVOID NK=MK1 AND NDEP=MDEP1 REQUIREMENT
C:
C:        90-08-14  MODIFICATIONS: (MATS CARLSSON)
C:        LOCAL OPERATOR VERSION
C:
      INCLUDE 'PREC'
      INCLUDE 'PARAM'
      INCLUDE 'PARAMW'
      INCLUDE 'CATOM'
      INCLUDE 'CATMOS'
      INCLUDE 'CATMO2'
      INCLUDE 'CTRAN'
      INCLUDE 'CSLINE'
      INCLUDE 'CGAUSI'
      INCLUDE 'CCONST'
      INCLUDE 'CINPUT'
      INCLUDE 'CLGMX'
      INCLUDE 'CLU'
      INCLUDE 'COPCL'
C
      DIMENSION W(MK1,MK1,MDEP1),E(MK1,MDEP1)
C
      CALL MCTIME('TOTAL ',0,0,5)
C
      CALL START
      IF(NK.GT.MK1) CALL STOP('MULTI: NK.GT.MK1')
      IF(NDEP.GT.MDEP1) CALL STOP('MULTI: NDEP.GT.MDEP1')
      NK1=NK
      NDEP1=NDEP
      CALL ITER(W,E,NK1,NDEP1)
      CALL FORMAL
C
      CALL MCTIME('TOTAL ',0,2,5)
      CALL STOP('NORMAL END')
      STOP
      END
C
C************************************************************************
C
